Helpers for Flask.
====================

Helpers for Flask.

安装
----

.. code-block:: sh

    pip install flask-zs


把models集中到models/__init__.py文件中(注：zsdemo为package name)::

    PYTHONPATH=. collect-models [zsdemo]
